numina.dal — Calibration fetching — Numina 0.20.dev0 documentation

# `numina.dal` — Calibration fetching

DAL base class

class `numina.dal.daliface.` `DALInterface`

  Abstract Base Class for DAL

DAL base classes

class `numina.dal.absdal.` `AbsDAL`

class `numina.dal.absdal.` `AbsDrpDAL`(drps, *args, **kwargs)

DAL for dictionary-based database of products.

class `numina.dal.dictdal.` `BaseDictDAL`(drps, ob_table, prod_table, req_table, extra_data=None)

  A dictionary based DAL

  `obsres_from_oblock_id`(obsid, configuration=None)

    ” Override instrument configuration if configuration is not None

  `search_prod_obsid`(ins, obsid, pipeline)

    Returns the first coincidence…

  `search_prod_type_tags`(tipo, ins, tags, pipeline)

    Returns the first coincidence…

class `numina.dal.dictdal.` `Dict2DAL`(drps, obtable, base, extra_data=None)

class `numina.dal.dictdal.` `DictDAL`(drps, base)

class `numina.dal.dictdal.` `HybridDAL`(drps, obtable, base, extra_data=None, basedir=None)

  A DAL that can read files from directory structure

DAL for file-based database of products.

DAL Mock class

class `numina.dal.mockdal.` `MockDAL`
  `search_prod_type_tags`(ins, type, tags, pipeline)

    Returns the first coincidence…

class `numina.dal.stored.` `StoredParameter`(content)

  A parameter returned from the DAL

class `numina.dal.stored.` `StoredProduct`(id, content, tags, **kwds)

  A product returned from the DAL

DAL for dictionary-based database of products.

class `numina.dal.backend.` `Backend`(drps, base, extra_data=None, basedir=None)

class `numina.dal.backend.` `StoredResult`

  Recover the RecipeResult values stored in the Backend

Utilities for DAL

`numina.dal.utils.` `tags_are_valid`(subset, superset)

  Validate tags